[][src]Struct tracing_timing::Downcaster

pub struct Downcaster<NH, S, E> { /* fields omitted */ }

A convenience type for getting access to TimingSubscriber through a Dispatch.

Methods

impl<NH, S, E> Downcaster<NH, S, E> where
    S: SpanGroup + 'static,
    E: EventGroup + 'static,
    S::Id: Clone + Hash + Eq + 'static,
    E::Id: Clone + Hash + Eq + 'static,
    NH: 'static, 
[src]

pub fn downcast<'a>(
    &self,
    d: &'a Dispatch
) -> Option<&'a TimingSubscriber<NH, S, E>>
[src]

Retrieve a reference to this ident's original TimingSubscriber.

This method returns None if the given Dispatch is not holding a subscriber of the same type as this ident was created from.