pub struct ByName;Expand description
Group spans/events by their “name”.
For spans, this is the string passed as the first argument to the various span tracing macros. For events, this is usually the source file and line number where the event was created.