[−][src]Struct tracing_timing::Builder
Builder for TimingSubscriber instances.
This type implements the builder pattern. It lets you easily configure and construct a new
TimingSubscriber subscriber. See the individual methods for details. To start, use
[Builder::from]:
use tracing_timing::{Builder, Histogram}; let builder = Builder::from(|| Histogram::new(3).unwrap()); let subscriber = builder.build();
See the various new_* methods on Histogram for how to construct an appropriate histogram
in the first place. All samples recorded by the subscriber returned from Builder::build
will be recorded into histograms as returned by the provided constructor.
Methods
impl<NH, S, E> Builder<NH, S, E>[src]
pub fn spans<S2>(self, span_group: S2) -> Builder<NH, S2, E>[src]
pub fn events<E2>(self, event_group: E2) -> Builder<NH, S, E2>[src]
Set the mechanism used to divide events into per-span groups.
See EventGroup and the group module for details.
pub fn time(self, time: Clock) -> Builder<NH, S, E>[src]
Set the time source to use for time measurements.
pub fn build(self) -> TimingSubscriber<NH, S, E> where
S: SpanGroup,
E: EventGroup,
S::Id: Hash + Eq,
E::Id: Hash + Eq,
NH: FnMut() -> Histogram<u64>, [src]
S: SpanGroup,
E: EventGroup,
S::Id: Hash + Eq,
E::Id: Hash + Eq,
NH: FnMut() -> Histogram<u64>,
Construct a TimingSubscriber as configured.